@@ -5,7 +5,7 @@ import os
 import uuid
 
 from flowui.cli.utils import platform, operators_repository
-
+import ast
 
 console = Console()
 
@@ -62,6 +62,9 @@ def get_dockerhub_password_from_env():
 def get_workflows_repository_from_env():
     return os.environ.get("FLOWUI_WORKFLOWS_REPOSITORY", None)
 
+def get_local_operators_repository_path():
+    return ""
+
 @click.command()
 @click.option(
     '--cluster-name', 
@@ -93,14 +96,44 @@ def get_workflows_repository_from_env():
     default=get_github_token_workflows_from_env,
     help='Github token for read/write operations on Workflows Repository.'
 )
-def cli_prepare_platform(cluster_name, workflows_repository, github_workflows_ssh_private_key, github_operators_token, github_workflows_token):
+@click.option(
+    '--dev-mode',
+    prompt='Development mode',
+    default="local",
+    help='Development mode - either "local" or "remote". If local it will allow you to use hot reloading for local operators repositories'
+)
+@click.option(
+    '--local-operators-repository-path',
+    prompt='Local operators repository path',
+    default=[],
+    help='List of local operators repository paths. It is used only if dev-mode is set to "local" and it will allow you to use hot reloading for local operators repositories.',
+)
+@click.option(
+    "--local-flowui-path",
+    prompt="Local FlowUI path",
+    default="",
+    help="Local FlowUI path. It is used only if dev-mode is set to 'local' and it will allow you to use hot reloading for local FlowUI.",
+)
+def cli_prepare_platform(
+    cluster_name,
+    workflows_repository,
+    github_workflows_ssh_private_key,
+    github_operators_token,
+    github_workflows_token,
+    dev_mode,
+    local_operators_repository_path,
+    local_flowui_path
+):
     """Prepare local folder for running a FlowUI platform."""
     platform.prepare_platform(
         cluster_name=cluster_name, 
         workflows_repository=workflows_repository,
         github_workflows_ssh_private_key=github_workflows_ssh_private_key, 
         github_operators_token=github_operators_token,
-        github_workflows_token=github_workflows_token
+        github_workflows_token=github_workflows_token,
+        dev_mode=dev_mode,
+        local_operators_repository_path=ast.literal_eval(local_operators_repository_path),
+        local_flowui_path=local_flowui_path
     )
 
 
