@@ -96,7 +96,7 @@ class FlowuiKubernetesPodOperator(KubernetesPodOperator):
         volume_mounts_sidecar_container = list()
         pod_volumes_list = list()
         for tid in self.shared_storage_upstream_ids_list:
-            tid_replaced = tid.replace("_", "-") # Doing this because k8s doesn't allow underscores in volume names
+            tid_replaced = tid.lower().replace("_", "-") # Doing this because k8s doesn't allow underscores in volume names
             volume_mounts_main_container.append(
                 k8s.V1VolumeMount(
                     name=f'workflow-shared-storage-volume-{tid_replaced}', 
